Embedded Kafka component for dev/testing
Embedded Kafka component for dev/testing
(embedded-kafka)(embedded-kafka config)Takes an optional config map with following keys:
Along with whatever other keys you want, which will be included.
Takes an optional config map with following keys: * :port Port to bind to on localhost [9092] * :log-dir Directory to store log data [random tmp dir] * :broker-id Kafka broker id [auto] Along with whatever other keys you want, which will be included.
(props config)Creates something usable as props (map of string=>string) from a config map.
Creates something usable as props (map of string=>string) from a config map.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |